summaryrefslogtreecommitdiff
path: root/src/history.cpp
diff options
context:
space:
mode:
authorAndrea Diamantini <adjam7@gmail.com>2009-10-02 16:20:18 +0200
committerAndrea Diamantini <adjam7@gmail.com>2009-10-02 16:20:18 +0200
commit79e11d892e2ff26636a647e91371aaef2c5d435d (patch)
tree48148f714597b96541f6feecb877fd6d31f1eff2 /src/history.cpp
parentSimpler KIO management (no more metadata) (diff)
downloadrekonq-79e11d892e2ff26636a647e91371aaef2c5d435d.tar.xz
moving from about: protocol to rekonq: protocol :D
This fix some issues, about some "stupid" sites whose js sends strange "about:blank" requests (just found 2!!)
Diffstat (limited to 'src/history.cpp')
-rw-r--r--src/history.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/history.cpp b/src/history.cpp
index 7e5cb741..aac3a66d 100644
--- a/src/history.cpp
+++ b/src/history.cpp
@@ -115,8 +115,8 @@ void HistoryManager::addHistoryEntry(const QString &url)
{
QUrl cleanUrl(url);
- // don't store about: urls (home page related)
- if(cleanUrl.scheme() == QString("about"))
+ // don't store rekonq: urls (home page related)
+ if(cleanUrl.scheme() == QString("rekonq"))
return;
cleanUrl.setPassword(QString());